##  Example
Let’s assume the IT strategy states that "Within the next two years we want to reduce our IT spend by 10%", consider the following aspects:
  * Scope: What does “we” refer to?
    * Is it the entire organization or only 2 out of 10 departments?
    * Who are your key stakeholders in the organization?
  * Cost Definition: What does “IT cost” mean?
    * Is it referring to total cost of ownership of specific applications or per business capability? Is it addressing costs like license, maintenance, and support that are part of total cost of owernship?
    * Is it referring to operating expenditure (OpEx) or capital expenditure (CapEx)?
    * What different data points do you need and where do you get them?
    * What is the business driver for reducing costs?
    * Besides cost, are there additional drivers that you need to be aware of?
  * Timeline: What does “within the next two years“ mean?
    * Is this a hard deadline?
    * Are there any management-specified milestones in between that you need to be aware of?
    * How do you measure and show the success of your initiative and what KPIs do you need to implement?


**Tip**
To get inspiration for relevant KPIs, have a look at the application rationalization dashboard in SAP LeanIX, see [Use Application Rationalization Dashboard](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report?locale=en-US&state=PRODUCTION&version=CLOUD#loio275d6c6f7a441014af49fbca7532cc3c__Use-Application-Rationalization-Dashboard).
